@@ -191,6 +191,7 @@ NVML_PERF_POLICY_COUNT = 2
 _nvmlSamplingType_t = c_uint
 NVML_TOTAL_POWER_SAMPLES = 0
 NVML_GPU_UTILIZATION_SAMPLES = 1
+
 NVML_MEMORY_UTILIZATION_SAMPLES = 2
 NVML_ENC_UTILIZATION_SAMPLES = 3
 NVML_DEC_UTILIZATION_SAMPLES = 4
@@ -1675,7 +1676,6 @@ def nvmlSystemGetTopologyGpuSet(cpuNumber):
 
     if ret != NVML_SUCCESS:
         raise NVMLError(ret)
-    print(c_count.value)
     # call again with a buffer
     device_array = c_nvmlDevice_t * c_count.value
     c_devices = device_array()
@@ -1705,4 +1705,36 @@ def nvmlDeviceGetTopologyCommonAncestor(device1, device2):
     fn = _nvmlGetFunctionPointer("nvmlDeviceGetTopologyCommonAncestor")
     ret = fn(device1, device2, byref(c_level))
     _nvmlCheckReturn(ret)
-    return c_level.value
\ No newline at end of file
+    return c_level.value
+
+
+# Added to pynvml.py 
+
+nvmlDeviceArchitecture_t = c_uint
+NVML_DEVICE_ARCH_KEPLER  = 2
+NVML_DEVICE_ARCH_MAXWELL = 3
+NVML_DEVICE_ARCH_PASCAL  = 4
+NVML_DEVICE_ARCH_VOLTA   = 5
+NVML_DEVICE_ARCH_TURING  = 6
+NVML_DEVICE_ARCH_AMPERE  = 7
+NVML_DEVICE_ARCH_UNKNOWN = 0
+
+def nvmlDeviceGetArchitecture(device):
+    c_arch = nvmlDeviceArchitecture_t()
+    fn = _nvmlGetFunctionPointer("nvmlDeviceGetArchitecture")
+    ret = fn(device, byref(c_arch))
+    _nvmlCheckReturn(ret)
+    return c_arch.value
+
+def nvmlDeviceGetCudaComputeCapability(device):
+    c_major = c_int()
+    c_minor = c_int()
+    fn = _nvmlGetFunctionPointer("nvmlDeviceGetCudaComputeCapability")
+    ret = fn(device, byref(c_major), byref(c_minor))
+    _nvmlCheckReturn(ret)
+    return c_major.value, c_minor.value
+
+
+
+
+
